from radio_bridge.radio_bridge import startRadioBridge
import uvloop, asyncio, signal, os
import argparse
import configparser
from pathlib import Path

def ask_exit(*args):
    STOP.set()

def ask_restart(*args):
    Path('/tmp/cnq-radio-bridge-restart').touch()
    RESTART.set()

if __name__ == '__main__':
    uvloop.install()
    loop = asyncio.get_event_loop()

    STOP = asyncio.Event()
    RESTART = asyncio.Event()

    loop.add_signal_handler(signal.SIGINT, ask_exit)
    loop.add_signal_handler(signal.SIGTERM, ask_exit)
    loop.add_signal_handler(signal.SIGHUP, ask_restart)


    parser = argparse.ArgumentParser()
    parser.add_argument('--networkId', default=10, type=int, help='The network ID from 0 to 255')
    parser.add_argument('--nodeId', default=1, type=int, help='The node ID from 0 to 254')

    args = parser.parse_args()

    parser = configparser.RawConfigParser()
    host = ''
    user = ''
    password = ''
    serialDevice = '/dev/ttyS2'
    serialSpeed = 115200

    with open("/etc/cnq-radio-bridge") as stream:
        parser.read_string(stream.read())
        host = parser['MQTT'].get('host', 'localhost')
        user = parser['MQTT'].get('username', '')
        password = parser['MQTT'].get('password', '')
        serialDevice = parser['UART'].get('device', '/dev/ttyS2')
        serialSpeed = parser['UART'].get('speed', 115200)

    restartIndicator = Path('/tmp/cnq-radio-bridge-restart')
    isRestarting = restartIndicator.is_file()

    if isRestarting:
        restartIndicator.unlink()
    
    loop.run_until_complete(startRadioBridge(args, host, user, password, serialDevice, serialSpeed, loop, STOP, RESTART, isRestarting))
    loop.close()
