import os
import sys
import time
import serial
from ymodem import YModem
from radio_bridge import HatControl


def readLine(serial_io, blocking):
    if blocking:
        print("[Gateway Hat]: " + serial_io.readline().decode("ascii"))

    while serial_io.inWaiting() > 0:
        print("[Gateway Hat]: " + serial_io.readline().decode("ascii"))

if __name__ == '__main__':
    if len(sys.argv) < 2:
        print("Usage: upload.py flashfile.bin [serialDevice] [baudrate]")
        exit(1)

    binaryFile = sys.argv[1]
    serialDevice = "/dev/ttyS1"
    bdRate = 500000 # CANIQUE devices run USART @ 500 kbps

    if len(sys.argv) > 2:
        serialDevice = sys.argv[2]

    if len(sys.argv) > 3:
        bdRate = int(sys.argv[3])


    print("Using serial device {} @ speed {} bps".format(serialDevice, bdRate))


    serial_io = serial.Serial(serialDevice, baudrate=bdRate, timeout=0.1)
    #serial_io.parity = "N"
    #serial_io.bytesize = 8
    #serial_io.stopbits = 1
    #serial_io.timeout = 2

    def sender_getc(size):
        return serial_io.read(size) or None

    def sender_putc(data, timeout=15):
        return serial_io.write(data)

    ## reset canique gateway hat
    hatControl = HatControl.HatControl()
    hatControl.reset()

    readLine(serial_io, True)

    sender = YModem.YModem(sender_getc, sender_putc, data_pad=b'\xFF')
    os.chdir(sys.path[0])

    print("Sending command 'd' for firmware upload to Canique device...")
    serial_io.write('d'.encode()) # start download - specific command to CANIQUE devices

    file_path = os.path.abspath(binaryFile)
    sent = sender.send_file(file_path)

    print("Sent {} bytes".format(sent))

    readLine(serial_io, False)

    if sent == os.path.getsize(file_path):
        print("Sending command 'r' ...")
        serial_io.write('r'.encode()) # run firmware - specific command to CANIQUE devices

    #wait until we get success msg (img must be decrypted/verified in this time)
    serial_io.timeout = 5.5
    readLine(serial_io, True)

    serial_io.close()
