import struct, array
import os, time

class TxProcessor(object):


    def __init__(self, ser):
        self.serialDevice = ser

    def transmitSensorConfig(self, sensorUID, config):
        if not config:
            return
        sensorConfigBytes = self.getSensorConfig(config)
        self.serialDevice.write('PP'.encode())
        self.serialDevice.write(bytearray([len(sensorConfigBytes) + 4]))
        self.serialDevice.write(struct.pack(">L", int(sensorUID))) #print sensor UID as 4 bytes
        self.serialDevice.write(sensorConfigBytes)
        self.serialDevice.flush()
        print("Sent sensor config for node {} to gateway module".format(sensorUID))

    def getSensorConfig(self, config):
        sensorConfigBytes = ''
        if config:
            sensorType = int(config['sensorType'])
            generalConfig = int(config['sleepCycles']) | int(config['useLed']) << 7 | int(config['txPower']) << 4

            if sensorType == 3: #distance sensor
                preRange = int(config['vcselPeriodPreRange']) - 11
                finalRange = int(config['vcselPeriodFinalRange']) - 7
                rangeConfig = preRange<<5 | finalRange<<2
                sensorConfigBytes = struct.pack(">B", generalConfig) + struct.pack(">B", int(float(config['signalRateLimit'])*100)) + struct.pack(">B", rangeConfig) + struct.pack(">B", int(config['measurementTimingBudget']))
            elif sensorType == 1 or sensorType == 5: #reed sensor / weather sensor
                #we need 11 bits for numbers < 2048min (~34h)
                sleepMinutesBeforeBattMeasure = int(config['preBatteryMeasurementDelayMin'])

                #preBattMeasureDelay = (int)(int(config['preBatteryMeasurementDelay'])/10)
                #voltageCorrection = int(10000 * float(config['voltageCorrection']) - 10000) #number between -512 and +511
                #temperatureOffset = int(config['temperatureOffset'])

                #if voltageCorrection < 0:
                #    #convert negative number to its positive uint16 representation (the bits stay exactly the same)
                #    voltageCorrection = 65536 + voltageCorrection

                #clear first 4 bits because temperatureOffset will be stored there
                #voltageCorrection &= 0x0FFF

                #if temperatureOffset < 0:
                    #convert negative number to its positive uint16 representation (the bits stay exactly the same)
                #    temperatureOffset = 65536 + (temperatureOffset<<12) #shift temperatureOffset to the first 4 bits of the 16bit value first
                #else:
                #    temperatureOffset = (temperatureOffset<<12)

                #first 4 bits are signed temp offset, next 12 bits are signed voltage correction
                #calibration = temperatureOffset | voltageCorrection

                sensorConfigBytes = struct.pack(">B", generalConfig) + struct.pack(">H", sleepMinutesBeforeBattMeasure)
                #print "Temp offset %s, voltage correction %s" % (temperatureOffset, voltageCorrection)
                #print binascii.hexlify(sensorConfigBytes)

            #TODO check if list index is empty... use different classes for converting config to bytes depending on sensor type
        return sensorConfigBytes
