from . import Reed1Parser
from . import DistanceParser
from . import DistanceAndVoltageParser
from . import WeatherParser
from . import HeaterParser
from . import HelloMsgParser

class SensorMsgParser:
	parsers = {}

	def __init__(self):
		self.parsers[1] = Reed1Parser.Reed1Parser()
		self.parsers[2] = Reed1Parser.Reed1Parser(withVoltage=True)
		#self.parsers[3] = DistanceParser.DistanceParser()
		#self.parsers[4] = DistanceAndVoltageParser.DistanceAndVoltageParser()
		self.parsers[5] = WeatherParser.WeatherParser()
		self.parsers[6] = WeatherParser.WeatherParser(withVoltage=True)
		self.parsers[7] = WeatherParser.WeatherParser(deltaEncoding=True)
		self.parsers[99] = HelloMsgParser.HelloMsgParser()
		self.parsers[100] = HeaterParser.HeaterParser() #anything >= 100 is an actor waiting for msgs

	def parse(self, msg):
		if len(msg) < 1:
			print ("Msg length is 0")
			return {}

		# check sensortype and parse rest of msg according to sensor specification
		sensorType = int(msg[0])

		if sensorType in self.parsers:
			parsed = self.parsers[sensorType].parse(msg)
			parsed['sensorType'] = sensorType
			return parsed
		else:
			print("Invalid sensor type found: %s" % (sensorType))

		return {}

	def getParser(self, msg):
		if len(msg) < 1:
			print ("Msg length is 0")
			return None

		# check sensortype and parse rest of msg according to sensor specification
		sensorType = int(msg[0])

		if sensorType in self.parsers:
			return self.parsers[sensorType]
		else:
			print("Invalid sensor type found: %s" % (sensorType))

		return None

	def toString(self, msg):
		output = ''
		for k,v in msg.items():
			output += '%s=%s;' % (k, v)

		return output
