import struct
from ..publisher import AirPublisher

class WeatherParser:

	TEMPERATURE_HISTORY = {}
	HUMIDITY_HISTORY = {}

	def __init__(self, deltaEncoding=False, withVoltage=False):
		self.withVoltage = withVoltage
		self.deltaEncoding = deltaEncoding

	def parse(self, txUID, msg):
		parsed = {}

		if self.deltaEncoding:
			temperatureDelta = struct.unpack(">b", msg[1:2])[0] #signed 1 byte integer
			humidityDelta = struct.unpack(">b", msg[2:3])[0] #signed 1 byte integer

			if txUID in self.TEMPERATURE_HISTORY and txUID in self.HUMIDITY_HISTORY:
				temperature = self.TEMPERATURE_HISTORY[txUID] + temperatureDelta
				humidity = self.HUMIDITY_HISTORY[txUID] + humidityDelta
				parsed['temperature'] = temperature
				parsed['humidity'] = humidity
			else:
				return parsed
		else:
			temperature = struct.unpack(">h", msg[1:3])[0] #signed 2 byte integer
			parsed['temperature'] = temperature

			humidity = struct.unpack(">H", msg[3:5])[0]
			parsed['humidity'] = humidity

		self.TEMPERATURE_HISTORY[txUID] = temperature
		self.HUMIDITY_HISTORY[txUID] = humidity

		if self.withVoltage:
			voltage = struct.unpack(">H", msg[5:7])[0]
			parsed['voltage'] = voltage & 0xFFF # wipe first 4 bits of this 2 byte number

		return parsed

	def getPublisher(self, mqttClient):
		return AirPublisher.AirPublisher(mqttClient)
