import json, math
from . import Publisher

class AirPublisher(Publisher.Publisher):

    def __init__(self, mqttClient):
        super().__init__(mqttClient)

    def publish(self, sensorId, timestamp, parsedMsg, rssi):
        if not 'temperature' in parsedMsg or not 'humidity' in parsedMsg:
            return

        temperature = parsedMsg['temperature']/100
        rH = parsedMsg['humidity']/100

        jsonObj = {'ts': timestamp, 'sid': sensorId, 'hdt': rH,
        'aH': round(self.calculateAbsoluteHumidity(temperature, rH), 2),
        'tmp': temperature, 'rssi': rssi}

        jsonStr = json.dumps(jsonObj)
        self.mqttClient.publish('sensors/air/{}/reading'.format(sensorId), jsonStr, qos=1, retain=True, content_type='cnq/0.1+json')

        super().publishBatteryStatus('air', sensorId, timestamp, parsedMsg)

    #from https://carnotcycle.wordpress.com/2012/08/04/how-to-convert-relative-humidity-to-absolute-humidity/ (<0.1% error for -30° to 35° C)
    #see also https://www.hatchability.com/Vaisala.pdf
    def calculateAbsoluteHumidity(self, temperature, rH): #in g/m³
        p1 = 6.112 * math.exp((17.67 * temperature) / (243.5 + temperature)) * rH * 2.1674
        p2 = (273.15 + temperature)
        return p1 / p2
